# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from collibra_core.configuration import Configuration


class AddCommentRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'content': 'str',
        'base_resource': 'ResourceReference',
        'parent_id': 'str',
        'base_resource_id': 'str',
        'base_resource_type': 'str'
    }

    attribute_map = {
        'content': 'content',
        'base_resource': 'baseResource',
        'parent_id': 'parentId',
        'base_resource_id': 'baseResourceId',
        'base_resource_type': 'baseResourceType'
    }

    def __init__(self, content=None, base_resource=None, parent_id=None, base_resource_id=None, base_resource_type=None, local_vars_configuration=None):  # noqa: E501
        """AddCommentRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._content = None
        self._base_resource = None
        self._parent_id = None
        self._base_resource_id = None
        self._base_resource_type = None
        self.discriminator = None

        self.content = content
        self.base_resource = base_resource
        if parent_id is not None:
            self.parent_id = parent_id
        if base_resource_id is not None:
            self.base_resource_id = base_resource_id
        if base_resource_type is not None:
            self.base_resource_type = base_resource_type

    @property
    def content(self):
        """Gets the content of this AddCommentRequest.  # noqa: E501

        The actual HTML content of the comment to be added. Can contain user mentions using syntax [@User:$userId] where $userId is the ID of mentioned user.For example: [@User:00000000-0000-0000-0000-000000900002].  # noqa: E501

        :return: The content of this AddCommentRequest.  # noqa: E501
        :rtype: str
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this AddCommentRequest.

        The actual HTML content of the comment to be added. Can contain user mentions using syntax [@User:$userId] where $userId is the ID of mentioned user.For example: [@User:00000000-0000-0000-0000-000000900002].  # noqa: E501

        :param content: The content of this AddCommentRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and content is None:  # noqa: E501
            raise ValueError("Invalid value for `content`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                content is not None and len(content) > 2147483647):
            raise ValueError("Invalid value for `content`, length must be less than or equal to `2147483647`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                content is not None and len(content) < 1):
            raise ValueError("Invalid value for `content`, length must be greater than or equal to `1`")  # noqa: E501

        self._content = content

    @property
    def base_resource(self):
        """Gets the base_resource of this AddCommentRequest.  # noqa: E501


        :return: The base_resource of this AddCommentRequest.  # noqa: E501
        :rtype: ResourceReference
        """
        return self._base_resource

    @base_resource.setter
    def base_resource(self, base_resource):
        """Sets the base_resource of this AddCommentRequest.


        :param base_resource: The base_resource of this AddCommentRequest.  # noqa: E501
        :type: ResourceReference
        """
        if self.local_vars_configuration.client_side_validation and base_resource is None:  # noqa: E501
            raise ValueError("Invalid value for `base_resource`, must not be `None`")  # noqa: E501

        self._base_resource = base_resource

    @property
    def parent_id(self):
        """Gets the parent_id of this AddCommentRequest.  # noqa: E501

        The ID of the parent comment. If not null - the comment is the reply for the parent comment.  # noqa: E501

        :return: The parent_id of this AddCommentRequest.  # noqa: E501
        :rtype: str
        """
        return self._parent_id

    @parent_id.setter
    def parent_id(self, parent_id):
        """Sets the parent_id of this AddCommentRequest.

        The ID of the parent comment. If not null - the comment is the reply for the parent comment.  # noqa: E501

        :param parent_id: The parent_id of this AddCommentRequest.  # noqa: E501
        :type: str
        """

        self._parent_id = parent_id

    @property
    def base_resource_id(self):
        """Gets the base_resource_id of this AddCommentRequest.  # noqa: E501


        :return: The base_resource_id of this AddCommentRequest.  # noqa: E501
        :rtype: str
        """
        return self._base_resource_id

    @base_resource_id.setter
    def base_resource_id(self, base_resource_id):
        """Sets the base_resource_id of this AddCommentRequest.


        :param base_resource_id: The base_resource_id of this AddCommentRequest.  # noqa: E501
        :type: str
        """

        self._base_resource_id = base_resource_id

    @property
    def base_resource_type(self):
        """Gets the base_resource_type of this AddCommentRequest.  # noqa: E501


        :return: The base_resource_type of this AddCommentRequest.  # noqa: E501
        :rtype: str
        """
        return self._base_resource_type

    @base_resource_type.setter
    def base_resource_type(self, base_resource_type):
        """Sets the base_resource_type of this AddCommentRequest.


        :param base_resource_type: The base_resource_type of this AddCommentRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["View", "Asset", "Community", "Domain", "AssetType", "DomainType", "Status", "User", "ClassificationMatch", "UserGroup", "Attribute", "StringAttribute", "ScriptAttribute", "BooleanAttribute", "DateAttribute", "NumericAttribute", "SingleValueListAttribute", "MultiValueListAttribute", "Comment", "Attachment", "Responsibility", "Workflow", "Job", "Relation", "RelationType", "ComplexRelation", "ComplexRelationType", "ArticulationRule", "Assignment", "Scope", "RelationTrace", "ValidationRule", "DataQualityRule", "DataQualityMetric", "Address", "InstantMessagingAccount", "Email", "PhoneNumber", "Website", "Activity", "FormProperty", "WorkflowTask", "ActivityChange", "WorkflowInstance", "Role", "AttributeType", "BooleanAttributeType", "DateAttributeType", "DateTimeAttributeType", "MultiValueListAttributeType", "NumericAttributeType", "ScriptAttributeType", "SingleValueListAttributeType", "StringAttributeType", "ViewSharingRule", "ViewAssignmentRule", "JdbcDriverFile", "JdbcDriver", "JdbcIngestionProperties", "CsvIngestionProperties", "ExcelIngestionProperties", "ConnectionStringParameter", "AssignedCharacteristicType", "Notification", "Tag", "ComplexRelationLegType", "ComplexRelationAttributeType", "ComplexRelationLeg", "BaseDataType", "AdvancedDataType", "DiagramPicture", "DiagramPictureSharingRule", "DiagramPictureAssignmentRule", "Rating", "Classification", "PhysicalDataConnector", "Context"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and base_resource_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `base_resource_type` ({0}), must be one of {1}"  # noqa: E501
                .format(base_resource_type, allowed_values)
            )

        self._base_resource_type = base_resource_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddCommentRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AddCommentRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import collibra_core
from collibra_core.models.add_data_quality_rule_request import AddDataQualityRuleRequest  # noqa: E501
from collibra_core.rest import ApiException

class TestAddDataQualityRuleRequest(unittest.TestCase):
    """AddDataQualityRuleRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AddDataQualityRuleRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = collibra_core.models.add_data_quality_rule_request.AddDataQualityRuleRequest()  # noqa: E501
        if include_optional :
            return AddDataQualityRuleRequest(
                id = '0', 
                name = '0', 
                description = '0', 
                categorization_relation_type_id = '0', 
                data_quality_metrics = [
                    collibra_core.models.data_quality_metric_request.DataQualityMetricRequest(
                        count_operation = 'Sum', 
                        attribute_type_id = '0', )
                    ], 
                relation_trace_entries = [
                    collibra_core.models.relation_trace_entry_request.RelationTraceEntryRequest(
                        role_direction = True, 
                        relation_type_id = '0', )
                    ]
            )
        else :
            return AddDataQualityRuleRequest(
                name = '0',
                categorization_relation_type_id = '0',
                relation_trace_entries = [
                    collibra_core.models.relation_trace_entry_request.RelationTraceEntryRequest(
                        role_direction = True, 
                        relation_type_id = '0', )
                    ],
        )

    def testAddDataQualityRuleRequest(self):
        """Test AddDataQualityRuleRequest"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from collibra_core.configuration import Configuration


class AddComplexRelationTypeRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'name': 'str',
        'description': 'str',
        'color': 'str',
        'symbol_type': 'str',
        'icon_code': 'str',
        'acronym_code': 'str',
        'attribute_types': 'list[ComplexRelationAttributeTypeRequest]',
        'leg_types': 'list[ComplexRelationLegTypeRequest]'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'description': 'description',
        'color': 'color',
        'symbol_type': 'symbolType',
        'icon_code': 'iconCode',
        'acronym_code': 'acronymCode',
        'attribute_types': 'attributeTypes',
        'leg_types': 'legTypes'
    }

    def __init__(self, id=None, name=None, description=None, color=None, symbol_type=None, icon_code=None, acronym_code=None, attribute_types=None, leg_types=None, local_vars_configuration=None):  # noqa: E501
        """AddComplexRelationTypeRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self._description = None
        self._color = None
        self._symbol_type = None
        self._icon_code = None
        self._acronym_code = None
        self._attribute_types = None
        self._leg_types = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.name = name
        if description is not None:
            self.description = description
        if color is not None:
            self.color = color
        self.symbol_type = symbol_type
        if icon_code is not None:
            self.icon_code = icon_code
        if acronym_code is not None:
            self.acronym_code = acronym_code
        self.attribute_types = attribute_types
        self.leg_types = leg_types

    @property
    def id(self):
        """Gets the id of this AddComplexRelationTypeRequest.  # noqa: E501

        The ID of the new Complex Relation Type. Should be unique within all Complex Relation Types.<br/>It should have a format of universally unique identifier (UUID) and should not start with <code>00000000-0000-0000-</code> which is a reserved prefix.  # noqa: E501

        :return: The id of this AddComplexRelationTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this AddComplexRelationTypeRequest.

        The ID of the new Complex Relation Type. Should be unique within all Complex Relation Types.<br/>It should have a format of universally unique identifier (UUID) and should not start with <code>00000000-0000-0000-</code> which is a reserved prefix.  # noqa: E501

        :param id: The id of this AddComplexRelationTypeRequest.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this AddComplexRelationTypeRequest.  # noqa: E501

        The name of the new Complex Relation Type. Should be unique within all Complex Relation Types.  # noqa: E501

        :return: The name of this AddComplexRelationTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AddComplexRelationTypeRequest.

        The name of the new Complex Relation Type. Should be unique within all Complex Relation Types.  # noqa: E501

        :param name: The name of this AddComplexRelationTypeRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 255):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `255`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def description(self):
        """Gets the description of this AddComplexRelationTypeRequest.  # noqa: E501

        The description of the new Complex Relation Type.  # noqa: E501

        :return: The description of this AddComplexRelationTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this AddComplexRelationTypeRequest.

        The description of the new Complex Relation Type.  # noqa: E501

        :param description: The description of this AddComplexRelationTypeRequest.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                description is not None and len(description) > 4000):
            raise ValueError("Invalid value for `description`, length must be less than or equal to `4000`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                description is not None and len(description) < 0):
            raise ValueError("Invalid value for `description`, length must be greater than or equal to `0`")  # noqa: E501

        self._description = description

    @property
    def color(self):
        """Gets the color of this AddComplexRelationTypeRequest.  # noqa: E501

        The color of the symbol, in a hex format e.g. '#000000'.  This format always includes the '#' and has a size of 7.  # noqa: E501

        :return: The color of this AddComplexRelationTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._color

    @color.setter
    def color(self, color):
        """Sets the color of this AddComplexRelationTypeRequest.

        The color of the symbol, in a hex format e.g. '#000000'.  This format always includes the '#' and has a size of 7.  # noqa: E501

        :param color: The color of this AddComplexRelationTypeRequest.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                color is not None and len(color) > 7):
            raise ValueError("Invalid value for `color`, length must be less than or equal to `7`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                color is not None and len(color) < 0):
            raise ValueError("Invalid value for `color`, length must be greater than or equal to `0`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                color is not None and not re.search(r'^#([A-Fa-f0-9]{6})$', color)):  # noqa: E501
            raise ValueError(r"Invalid value for `color`, must be a follow pattern or equal to `/^#([A-Fa-f0-9]{6})$/`")  # noqa: E501

        self._color = color

    @property
    def symbol_type(self):
        """Gets the symbol_type of this AddComplexRelationTypeRequest.  # noqa: E501

        The symbol type.  # noqa: E501

        :return: The symbol_type of this AddComplexRelationTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._symbol_type

    @symbol_type.setter
    def symbol_type(self, symbol_type):
        """Sets the symbol_type of this AddComplexRelationTypeRequest.

        The symbol type.  # noqa: E501

        :param symbol_type: The symbol_type of this AddComplexRelationTypeRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and symbol_type is None:  # noqa: E501
            raise ValueError("Invalid value for `symbol_type`, must not be `None`")  # noqa: E501
        allowed_values = ["NONE", "ICON_CODE", "ACRONYM_CODE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and symbol_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `symbol_type` ({0}), must be one of {1}"  # noqa: E501
                .format(symbol_type, allowed_values)
            )

        self._symbol_type = symbol_type

    @property
    def icon_code(self):
        """Gets the icon_code of this AddComplexRelationTypeRequest.  # noqa: E501

        The icon code of the new Complex Relation Type.  # noqa: E501

        :return: The icon_code of this AddComplexRelationTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._icon_code

    @icon_code.setter
    def icon_code(self, icon_code):
        """Sets the icon_code of this AddComplexRelationTypeRequest.

        The icon code of the new Complex Relation Type.  # noqa: E501

        :param icon_code: The icon_code of this AddComplexRelationTypeRequest.  # noqa: E501
        :type: str
        """

        self._icon_code = icon_code

    @property
    def acronym_code(self):
        """Gets the acronym_code of this AddComplexRelationTypeRequest.  # noqa: E501

        The acronym code of the new Complex Relation Type.  # noqa: E501

        :return: The acronym_code of this AddComplexRelationTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._acronym_code

    @acronym_code.setter
    def acronym_code(self, acronym_code):
        """Sets the acronym_code of this AddComplexRelationTypeRequest.

        The acronym code of the new Complex Relation Type.  # noqa: E501

        :param acronym_code: The acronym_code of this AddComplexRelationTypeRequest.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                acronym_code is not None and not re.search(r'^([A-Za-z0-9]{1,4})$', acronym_code)):  # noqa: E501
            raise ValueError(r"Invalid value for `acronym_code`, must be a follow pattern or equal to `/^([A-Za-z0-9]{1,4})$/`")  # noqa: E501

        self._acronym_code = acronym_code

    @property
    def attribute_types(self):
        """Gets the attribute_types of this AddComplexRelationTypeRequest.  # noqa: E501

        The list of attribute types for the new Complex Relation Type.  # noqa: E501

        :return: The attribute_types of this AddComplexRelationTypeRequest.  # noqa: E501
        :rtype: list[ComplexRelationAttributeTypeRequest]
        """
        return self._attribute_types

    @attribute_types.setter
    def attribute_types(self, attribute_types):
        """Sets the attribute_types of this AddComplexRelationTypeRequest.

        The list of attribute types for the new Complex Relation Type.  # noqa: E501

        :param attribute_types: The attribute_types of this AddComplexRelationTypeRequest.  # noqa: E501
        :type: list[ComplexRelationAttributeTypeRequest]
        """
        if self.local_vars_configuration.client_side_validation and attribute_types is None:  # noqa: E501
            raise ValueError("Invalid value for `attribute_types`, must not be `None`")  # noqa: E501

        self._attribute_types = attribute_types

    @property
    def leg_types(self):
        """Gets the leg_types of this AddComplexRelationTypeRequest.  # noqa: E501

        The list of leg types for the new Complex Relation Type.  # noqa: E501

        :return: The leg_types of this AddComplexRelationTypeRequest.  # noqa: E501
        :rtype: list[ComplexRelationLegTypeRequest]
        """
        return self._leg_types

    @leg_types.setter
    def leg_types(self, leg_types):
        """Sets the leg_types of this AddComplexRelationTypeRequest.

        The list of leg types for the new Complex Relation Type.  # noqa: E501

        :param leg_types: The leg_types of this AddComplexRelationTypeRequest.  # noqa: E501
        :type: list[ComplexRelationLegTypeRequest]
        """
        if self.local_vars_configuration.client_side_validation and leg_types is None:  # noqa: E501
            raise ValueError("Invalid value for `leg_types`, must not be `None`")  # noqa: E501

        self._leg_types = leg_types

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddComplexRelationTypeRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AddComplexRelationTypeRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import collibra_core
from collibra_core.api.workflow_definitions_api import WorkflowDefinitionsApi  # noqa: E501
from collibra_core.rest import ApiException


class TestWorkflowDefinitionsApi(unittest.TestCase):
    """WorkflowDefinitionsApi unit test stubs"""

    def setUp(self):
        self.api = collibra_core.api.workflow_definitions_api.WorkflowDefinitionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_asset_type_assignment_rule(self):
        """Test case for add_asset_type_assignment_rule

        Add asset type assignment rule.  # noqa: E501
        """
        pass

    def test_add_domain_type_assignment_rule(self):
        """Test case for add_domain_type_assignment_rule

        Add domain type assignment rule.  # noqa: E501
        """
        pass

    def test_change_asset_type_assignment_rule(self):
        """Test case for change_asset_type_assignment_rule

        Change asset type assignment rule.  # noqa: E501
        """
        pass

    def test_change_domain_type_assignment_rule(self):
        """Test case for change_domain_type_assignment_rule

        Change domain type assignment rule.  # noqa: E501
        """
        pass

    def test_change_workflow_definition(self):
        """Test case for change_workflow_definition

        Change workflow definition.  # noqa: E501
        """
        pass

    def test_deploy_workflow_definition(self):
        """Test case for deploy_workflow_definition

        Deploy workflow definition.  # noqa: E501
        """
        pass

    def test_find_workflow_definitions(self):
        """Test case for find_workflow_definitions

        Find workflow definitions.  # noqa: E501
        """
        pass

    def test_get_configuration_start_form_data(self):
        """Test case for get_configuration_start_form_data

        Get configuration start form data.  # noqa: E501
        """
        pass

    def test_get_possible_start_events(self):
        """Test case for get_possible_start_events

        Get all possible workflow start events  # noqa: E501
        """
        pass

    def test_get_start_form_data(self):
        """Test case for get_start_form_data

        Get start form data.  # noqa: E501
        """
        pass

    def test_get_workflow_definition(self):
        """Test case for get_workflow_definition

        Get workflow definition.  # noqa: E501
        """
        pass

    def test_get_workflow_definition_by_process_id(self):
        """Test case for get_workflow_definition_by_process_id

        Get workflow definition.  # noqa: E501
        """
        pass

    def test_get_workflow_definition_diagram(self):
        """Test case for get_workflow_definition_diagram

        Get process diagram.  # noqa: E501
        """
        pass

    def test_get_workflow_definition_xml(self):
        """Test case for get_workflow_definition_xml

        Get XML of workflow definition.  # noqa: E501
        """
        pass

    def test_remove_assignment_rule(self):
        """Test case for remove_assignment_rule

        Remove assignment rule.  # noqa: E501
        """
        pass

    def test_remove_workflow_definition(self):
        """Test case for remove_workflow_definition

        Remove workflow definition.  # noqa: E501
        """
        pass

    def test_remove_workflow_definitions_in_job(self):
        """Test case for remove_workflow_definitions_in_job

        Remove multiple workflow definitions.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from collibra_core.api_client import ApiClient
from collibra_core.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class DomainsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_domain(self, **kwargs):  # noqa: E501
        """Add domain  # noqa: E501

        Adds a new domain with given data into a community.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_domain(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddDomainRequest add_domain_request: the properties of the domain to be added
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DomainImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.add_domain_with_http_info(**kwargs)  # noqa: E501

    def add_domain_with_http_info(self, **kwargs):  # noqa: E501
        """Add domain  # noqa: E501

        Adds a new domain with given data into a community.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_domain_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddDomainRequest add_domain_request: the properties of the domain to be added
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DomainImpl, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'add_domain_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_domain" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_domain_request' in local_var_params:
            body_params = local_var_params['add_domain_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/domains', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DomainImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def add_domains(self, **kwargs):  # noqa: E501
        """Add multpile domains  # noqa: E501

        Adds multiple domains using the given parameters  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_domains(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[AddDomainRequest] add_domain_request: List of the properties of the domains to be added.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[DomainImpl]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.add_domains_with_http_info(**kwargs)  # noqa: E501

    def add_domains_with_http_info(self, **kwargs):  # noqa: E501
        """Add multpile domains  # noqa: E501

        Adds multiple domains using the given parameters  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_domains_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[AddDomainRequest] add_domain_request: List of the properties of the domains to be added.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[DomainImpl], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'add_domain_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_domains" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_domain_request' in local_var_params:
            body_params = local_var_params['add_domain_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/domains/bulk', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[DomainImpl]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def change_domain(self, domain_id, **kwargs):  # noqa: E501
        """Change domain  # noqa: E501

        Changes the domain with the information that is present in the request. Only properties that are specified in this request and have not <code>null</code> values are updated. All other properties are ignored.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_domain(domain_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str domain_id: the ID of the domain to be changed. (required)
        :param ChangeDomainRequest change_domain_request: the properties of the domain to be changed
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DomainImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.change_domain_with_http_info(domain_id, **kwargs)  # noqa: E501

    def change_domain_with_http_info(self, domain_id, **kwargs):  # noqa: E501
        """Change domain  # noqa: E501

        Changes the domain with the information that is present in the request. Only properties that are specified in this request and have not <code>null</code> values are updated. All other properties are ignored.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_domain_with_http_info(domain_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str domain_id: the ID of the domain to be changed. (required)
        :param ChangeDomainRequest change_domain_request: the properties of the domain to be changed
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DomainImpl, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'domain_id',
            'change_domain_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method change_domain" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'domain_id' is set
        if self.api_client.client_side_validation and ('domain_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['domain_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `domain_id` when calling `change_domain`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'domain_id' in local_var_params:
            path_params['domainId'] = local_var_params['domain_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'change_domain_request' in local_var_params:
            body_params = local_var_params['change_domain_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/domains/{domainId}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DomainImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def change_domains(self, **kwargs):  # noqa: E501
        """Change multiple domains  # noqa: E501

        Changes multiple domains using the given parameters  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_domains(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[ChangeDomainRequest] change_domain_request: List of the properties of the domains to be changed.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[DomainImpl]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.change_domains_with_http_info(**kwargs)  # noqa: E501

    def change_domains_with_http_info(self, **kwargs):  # noqa: E501
        """Change multiple domains  # noqa: E501

        Changes multiple domains using the given parameters  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_domains_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[ChangeDomainRequest] change_domain_request: List of the properties of the domains to be changed.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[DomainImpl], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'change_domain_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method change_domains" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'change_domain_request' in local_var_params:
            body_params = local_var_params['change_domain_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/domains/bulk', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[DomainImpl]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def find_domains(self, **kwargs):  # noqa: E501
        """Search domains  # noqa: E501

        Finds the domains that match the given search criteria. Only parameters that are specified in this request and have not <code>null</code> values are used for filtering. All other parameters are ignored. By default a result containing 1000 domains is returned.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_domains(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int offset: The first result to retrieve. If not set (offset = <code>0</code>), results will be retrieved starting from row <code>0</code>. Cursor should be preferred over offset for better performance and stable results. It is forbidden to use both in the same request.
        :param int limit: The maximum number of results to retrieve. If not set (limit = <code>0</code>), the default limit will be used.
        :param int count_limit: Allows to limit the number of elements that will be counted. -1 will count everything and 0 will cause the count to be skipped. For cursor pagination this parameter is ignored and count is skipped.
        :param str cursor: Cursor for current page of results. To retrieve first page with cursor pagination you need to pass this parameter with empty value. For next pages the value must be taken from response (<code>nextCursor</code> property).
        :param str name: The name of the domain to search for
        :param str name_match_mode: The match mode used to compare <code>name</code>. If the match mode is <code>EXACT</code> the search is case-sensitive, otherwise the search is case-insensitive.
        :param bool exclude_meta: The exclude meta flag. If this is set to true then the meta domains will not be returned<br/>(meta domains are i.e. domains not created manually by the user)
        :param str community_id: The ID of the community to find the domains in
        :param str type_id: The ID of the domain type to search for. Returned domains are of this type
        :param bool include_sub_communities: The include sub-communities flag. When set to true, sub-communities (of the community indicated via<br/>the <code>communityId</code> parameter) will be searched in.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DomainPagedResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.find_domains_with_http_info(**kwargs)  # noqa: E501

    def find_domains_with_http_info(self, **kwargs):  # noqa: E501
        """Search domains  # noqa: E501

        Finds the domains that match the given search criteria. Only parameters that are specified in this request and have not <code>null</code> values are used for filtering. All other parameters are ignored. By default a result containing 1000 domains is returned.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_domains_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int offset: The first result to retrieve. If not set (offset = <code>0</code>), results will be retrieved starting from row <code>0</code>. Cursor should be preferred over offset for better performance and stable results. It is forbidden to use both in the same request.
        :param int limit: The maximum number of results to retrieve. If not set (limit = <code>0</code>), the default limit will be used.
        :param int count_limit: Allows to limit the number of elements that will be counted. -1 will count everything and 0 will cause the count to be skipped. For cursor pagination this parameter is ignored and count is skipped.
        :param str cursor: Cursor for current page of results. To retrieve first page with cursor pagination you need to pass this parameter with empty value. For next pages the value must be taken from response (<code>nextCursor</code> property).
        :param str name: The name of the domain to search for
        :param str name_match_mode: The match mode used to compare <code>name</code>. If the match mode is <code>EXACT</code> the search is case-sensitive, otherwise the search is case-insensitive.
        :param bool exclude_meta: The exclude meta flag. If this is set to true then the meta domains will not be returned<br/>(meta domains are i.e. domains not created manually by the user)
        :param str community_id: The ID of the community to find the domains in
        :param str type_id: The ID of the domain type to search for. Returned domains are of this type
        :param bool include_sub_communities: The include sub-communities flag. When set to true, sub-communities (of the community indicated via<br/>the <code>communityId</code> parameter) will be searched in.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DomainPagedResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'offset',
            'limit',
            'count_limit',
            'cursor',
            'name',
            'name_match_mode',
            'exclude_meta',
            'community_id',
            'type_id',
            'include_sub_communities'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_domains" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offset' in local_var_params and local_var_params['offset'] is not None:  # noqa: E501
            query_params.append(('offset', local_var_params['offset']))  # noqa: E501
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
        if 'count_limit' in local_var_params and local_var_params['count_limit'] is not None:  # noqa: E501
            query_params.append(('countLimit', local_var_params['count_limit']))  # noqa: E501
        if 'cursor' in local_var_params and local_var_params['cursor'] is not None:  # noqa: E501
            query_params.append(('cursor', local_var_params['cursor']))  # noqa: E501
        if 'name' in local_var_params and local_var_params['name'] is not None:  # noqa: E501
            query_params.append(('name', local_var_params['name']))  # noqa: E501
        if 'name_match_mode' in local_var_params and local_var_params['name_match_mode'] is not None:  # noqa: E501
            query_params.append(('nameMatchMode', local_var_params['name_match_mode']))  # noqa: E501
        if 'exclude_meta' in local_var_params and local_var_params['exclude_meta'] is not None:  # noqa: E501
            query_params.append(('excludeMeta', local_var_params['exclude_meta']))  # noqa: E501
        if 'community_id' in local_var_params and local_var_params['community_id'] is not None:  # noqa: E501
            query_params.append(('communityId', local_var_params['community_id']))  # noqa: E501
        if 'type_id' in local_var_params and local_var_params['type_id'] is not None:  # noqa: E501
            query_params.append(('typeId', local_var_params['type_id']))  # noqa: E501
        if 'include_sub_communities' in local_var_params and local_var_params['include_sub_communities'] is not None:  # noqa: E501
            query_params.append(('includeSubCommunities', local_var_params['include_sub_communities']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/domains', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DomainPagedResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_domain(self, domain_id, **kwargs):  # noqa: E501
        """Get domain  # noqa: E501

        Returns the domain with the given ID  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_domain(domain_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str domain_id: the ID of the domain (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DomainImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_domain_with_http_info(domain_id, **kwargs)  # noqa: E501

    def get_domain_with_http_info(self, domain_id, **kwargs):  # noqa: E501
        """Get domain  # noqa: E501

        Returns the domain with the given ID  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_domain_with_http_info(domain_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str domain_id: the ID of the domain (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DomainImpl, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'domain_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_domain" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'domain_id' is set
        if self.api_client.client_side_validation and ('domain_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['domain_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `domain_id` when calling `get_domain`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'domain_id' in local_var_params:
            path_params['domainId'] = local_var_params['domain_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/domains/{domainId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DomainImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_domain_breadcrumb(self, domain_id, **kwargs):  # noqa: E501
        """Get domain breadcrumb  # noqa: E501

        Returns the list of resources that lead to the domain identified by the given ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_domain_breadcrumb(domain_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str domain_id: The ID of the domain (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[NamedResourceReferenceImpl]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_domain_breadcrumb_with_http_info(domain_id, **kwargs)  # noqa: E501

    def get_domain_breadcrumb_with_http_info(self, domain_id, **kwargs):  # noqa: E501
        """Get domain breadcrumb  # noqa: E501

        Returns the list of resources that lead to the domain identified by the given ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_domain_breadcrumb_with_http_info(domain_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str domain_id: The ID of the domain (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[NamedResourceReferenceImpl], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'domain_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_domain_breadcrumb" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'domain_id' is set
        if self.api_client.client_side_validation and ('domain_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['domain_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `domain_id` when calling `get_domain_breadcrumb`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'domain_id' in local_var_params:
            path_params['domainId'] = local_var_params['domain_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/domains/{domainId}/breadcrumb', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[NamedResourceReferenceImpl]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_domain(self, domain_id, **kwargs):  # noqa: E501
        """Remove domain  # noqa: E501

        This endpoint will be removed in the future. Please use POST /domains/removalJobs.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_domain(domain_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str domain_id: the ID of the domain to remove (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Job
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.remove_domain_with_http_info(domain_id, **kwargs)  # noqa: E501

    def remove_domain_with_http_info(self, domain_id, **kwargs):  # noqa: E501
        """Remove domain  # noqa: E501

        This endpoint will be removed in the future. Please use POST /domains/removalJobs.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_domain_with_http_info(domain_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str domain_id: the ID of the domain to remove (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Job, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'domain_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_domain" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'domain_id' is set
        if self.api_client.client_side_validation and ('domain_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['domain_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `domain_id` when calling `remove_domain`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'domain_id' in local_var_params:
            path_params['domainId'] = local_var_params['domain_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/domains/{domainId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Job',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_domains(self, **kwargs):  # noqa: E501
        """Remove multiple domains  # noqa: E501

        This endpoint will be removed in the future. Please use POST /domains/removalJobs.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_domains(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] request_body: the IDs of the domains to be removed, i.e. [\"6f685f90-1036-4d30-983a-a9bbcdd7b8f6\", \"6f685f90-1036-4d30-983a-a9bbcdd7b123\"]
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.remove_domains_with_http_info(**kwargs)  # noqa: E501

    def remove_domains_with_http_info(self, **kwargs):  # noqa: E501
        """Remove multiple domains  # noqa: E501

        This endpoint will be removed in the future. Please use POST /domains/removalJobs.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_domains_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] request_body: the IDs of the domains to be removed, i.e. [\"6f685f90-1036-4d30-983a-a9bbcdd7b8f6\", \"6f685f90-1036-4d30-983a-a9bbcdd7b123\"]
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'request_body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_domains" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request_body' in local_var_params:
            body_params = local_var_params['request_body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/domains/bulk', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_domains_in_job(self, **kwargs):  # noqa: E501
        """Remove multiple domains asynchronously  # noqa: E501

        Removes multiple domains with the given IDs in a job.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_domains_in_job(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] request_body: the IDs of the domains to be removed, i.e. [\"6f685f90-1036-4d30-983a-a9bbcdd7b8f6\", \"6f685f90-1036-4d30-983a-a9bbcdd7b123\"]
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Job
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.remove_domains_in_job_with_http_info(**kwargs)  # noqa: E501

    def remove_domains_in_job_with_http_info(self, **kwargs):  # noqa: E501
        """Remove multiple domains asynchronously  # noqa: E501

        Removes multiple domains with the given IDs in a job.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_domains_in_job_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] request_body: the IDs of the domains to be removed, i.e. [\"6f685f90-1036-4d30-983a-a9bbcdd7b8f6\", \"6f685f90-1036-4d30-983a-a9bbcdd7b123\"]
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Job, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'request_body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_domains_in_job" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request_body' in local_var_params:
            body_params = local_var_params['request_body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/domains/removalJobs', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Job',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from collibra_core.configuration import Configuration


class WorkflowDefinitionImpl(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'created_by': 'str',
        'created_on': 'int',
        'last_modified_by': 'str',
        'last_modified_on': 'int',
        'system': 'bool',
        'resource_type': 'str',
        'name': 'str',
        'description': 'str',
        'process_id': 'str',
        'start_label': 'str',
        'form_required': 'bool',
        'start_form_key_available': 'bool',
        'start_form_json_model_available': 'bool',
        'enabled': 'bool',
        'domain_assignment_rules': 'list[AssetAssignmentRuleImpl]',
        'asset_assignment_rules': 'list[AssetAssignmentRuleImpl]',
        'business_item_resource_type': 'str',
        'exclusivity': 'str',
        'guest_user_accessible': 'bool',
        'registered_user_accessible': 'bool',
        'candidate_user_check_enabled': 'bool',
        'global_create': 'bool',
        'start_events': 'list[str]',
        'configuration_variables': 'dict(str, str)',
        'start_roles': 'list[RoleImpl]',
        'stop_roles': 'list[RoleImpl]',
        'reassign_roles': 'list[RoleImpl]'
    }

    attribute_map = {
        'id': 'id',
        'created_by': 'createdBy',
        'created_on': 'createdOn',
        'last_modified_by': 'lastModifiedBy',
        'last_modified_on': 'lastModifiedOn',
        'system': 'system',
        'resource_type': 'resourceType',
        'name': 'name',
        'description': 'description',
        'process_id': 'processId',
        'start_label': 'startLabel',
        'form_required': 'formRequired',
        'start_form_key_available': 'startFormKeyAvailable',
        'start_form_json_model_available': 'startFormJsonModelAvailable',
        'enabled': 'enabled',
        'domain_assignment_rules': 'domainAssignmentRules',
        'asset_assignment_rules': 'assetAssignmentRules',
        'business_item_resource_type': 'businessItemResourceType',
        'exclusivity': 'exclusivity',
        'guest_user_accessible': 'guestUserAccessible',
        'registered_user_accessible': 'registeredUserAccessible',
        'candidate_user_check_enabled': 'candidateUserCheckEnabled',
        'global_create': 'globalCreate',
        'start_events': 'startEvents',
        'configuration_variables': 'configurationVariables',
        'start_roles': 'startRoles',
        'stop_roles': 'stopRoles',
        'reassign_roles': 'reassignRoles'
    }

    def __init__(self, id=None, created_by=None, created_on=None, last_modified_by=None, last_modified_on=None, system=None, resource_type=None, name=None, description=None, process_id=None, start_label=None, form_required=None, start_form_key_available=None, start_form_json_model_available=None, enabled=None, domain_assignment_rules=None, asset_assignment_rules=None, business_item_resource_type=None, exclusivity=None, guest_user_accessible=None, registered_user_accessible=None, candidate_user_check_enabled=None, global_create=None, start_events=None, configuration_variables=None, start_roles=None, stop_roles=None, reassign_roles=None, local_vars_configuration=None):  # noqa: E501
        """WorkflowDefinitionImpl - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._created_by = None
        self._created_on = None
        self._last_modified_by = None
        self._last_modified_on = None
        self._system = None
        self._resource_type = None
        self._name = None
        self._description = None
        self._process_id = None
        self._start_label = None
        self._form_required = None
        self._start_form_key_available = None
        self._start_form_json_model_available = None
        self._enabled = None
        self._domain_assignment_rules = None
        self._asset_assignment_rules = None
        self._business_item_resource_type = None
        self._exclusivity = None
        self._guest_user_accessible = None
        self._registered_user_accessible = None
        self._candidate_user_check_enabled = None
        self._global_create = None
        self._start_events = None
        self._configuration_variables = None
        self._start_roles = None
        self._stop_roles = None
        self._reassign_roles = None
        self.discriminator = None

        self.id = id
        if created_by is not None:
            self.created_by = created_by
        if created_on is not None:
            self.created_on = created_on
        if last_modified_by is not None:
            self.last_modified_by = last_modified_by
        if last_modified_on is not None:
            self.last_modified_on = last_modified_on
        if system is not None:
            self.system = system
        self.resource_type = resource_type
        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        if process_id is not None:
            self.process_id = process_id
        if start_label is not None:
            self.start_label = start_label
        if form_required is not None:
            self.form_required = form_required
        if start_form_key_available is not None:
            self.start_form_key_available = start_form_key_available
        if start_form_json_model_available is not None:
            self.start_form_json_model_available = start_form_json_model_available
        if enabled is not None:
            self.enabled = enabled
        if domain_assignment_rules is not None:
            self.domain_assignment_rules = domain_assignment_rules
        if asset_assignment_rules is not None:
            self.asset_assignment_rules = asset_assignment_rules
        if business_item_resource_type is not None:
            self.business_item_resource_type = business_item_resource_type
        if exclusivity is not None:
            self.exclusivity = exclusivity
        if guest_user_accessible is not None:
            self.guest_user_accessible = guest_user_accessible
        if registered_user_accessible is not None:
            self.registered_user_accessible = registered_user_accessible
        if candidate_user_check_enabled is not None:
            self.candidate_user_check_enabled = candidate_user_check_enabled
        if global_create is not None:
            self.global_create = global_create
        if start_events is not None:
            self.start_events = start_events
        if configuration_variables is not None:
            self.configuration_variables = configuration_variables
        if start_roles is not None:
            self.start_roles = start_roles
        if stop_roles is not None:
            self.stop_roles = stop_roles
        if reassign_roles is not None:
            self.reassign_roles = reassign_roles

    @property
    def id(self):
        """Gets the id of this WorkflowDefinitionImpl.  # noqa: E501

        The id of the represented object (entity).  # noqa: E501

        :return: The id of this WorkflowDefinitionImpl.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this WorkflowDefinitionImpl.

        The id of the represented object (entity).  # noqa: E501

        :param id: The id of this WorkflowDefinitionImpl.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def created_by(self):
        """Gets the created_by of this WorkflowDefinitionImpl.  # noqa: E501

        The id of the user that created this resource.  # noqa: E501

        :return: The created_by of this WorkflowDefinitionImpl.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this WorkflowDefinitionImpl.

        The id of the user that created this resource.  # noqa: E501

        :param created_by: The created_by of this WorkflowDefinitionImpl.  # noqa: E501
        :type: str
        """

        self._created_by = created_by

    @property
    def created_on(self):
        """Gets the created_on of this WorkflowDefinitionImpl.  # noqa: E501

        The timestamp (in UTC time standard) of the creation of this resource.  # noqa: E501

        :return: The created_on of this WorkflowDefinitionImpl.  # noqa: E501
        :rtype: int
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this WorkflowDefinitionImpl.

        The timestamp (in UTC time standard) of the creation of this resource.  # noqa: E501

        :param created_on: The created_on of this WorkflowDefinitionImpl.  # noqa: E501
        :type: int
        """

        self._created_on = created_on

    @property
    def last_modified_by(self):
        """Gets the last_modified_by of this WorkflowDefinitionImpl.  # noqa: E501

        The id of the user who modified this resource the last time.  # noqa: E501

        :return: The last_modified_by of this WorkflowDefinitionImpl.  # noqa: E501
        :rtype: str
        """
        return self._last_modified_by

    @last_modified_by.setter
    def last_modified_by(self, last_modified_by):
        """Sets the last_modified_by of this WorkflowDefinitionImpl.

        The id of the user who modified this resource the last time.  # noqa: E501

        :param last_modified_by: The last_modified_by of this WorkflowDefinitionImpl.  # noqa: E501
        :type: str
        """

        self._last_modified_by = last_modified_by

    @property
    def last_modified_on(self):
        """Gets the last_modified_on of this WorkflowDefinitionImpl.  # noqa: E501

        The timestamp (in UTC time standard) of the last modification of this resource.  # noqa: E501

        :return: The last_modified_on of this WorkflowDefinitionImpl.  # noqa: E501
        :rtype: int
        """
        return self._last_modified_on

    @last_modified_on.setter
    def last_modified_on(self, last_modified_on):
        """Sets the last_modified_on of this WorkflowDefinitionImpl.

        The timestamp (in UTC time standard) of the last modification of this resource.  # noqa: E501

        :param last_modified_on: The last_modified_on of this WorkflowDefinitionImpl.  # noqa: E501
        :type: int
        """

        self._last_modified_on = last_modified_on

    @property
    def system(self):
        """Gets the system of this WorkflowDefinitionImpl.  # noqa: E501

        Whether this is a system resource or not.  # noqa: E501

        :return: The system of this WorkflowDefinitionImpl.  # noqa: E501
        :rtype: bool
        """
        return self._system

    @system.setter
    def system(self, system):
        """Sets the system of this WorkflowDefinitionImpl.

        Whether this is a system resource or not.  # noqa: E501

        :param system: The system of this WorkflowDefinitionImpl.  # noqa: E501
        :type: bool
        """

        self._system = system

    @property
    def resource_type(self):
        """Gets the resource_type of this WorkflowDefinitionImpl.  # noqa: E501

        The type of this resource, i.e. [Community, Asset, Domain, Attribute, Relation, WorkflowInstance].  # noqa: E501

        :return: The resource_type of this WorkflowDefinitionImpl.  # noqa: E501
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this WorkflowDefinitionImpl.

        The type of this resource, i.e. [Community, Asset, Domain, Attribute, Relation, WorkflowInstance].  # noqa: E501

        :param resource_type: The resource_type of this WorkflowDefinitionImpl.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and resource_type is None:  # noqa: E501
            raise ValueError("Invalid value for `resource_type`, must not be `None`")  # noqa: E501
        allowed_values = ["View", "Asset", "Community", "Domain", "AssetType", "DomainType", "Status", "User", "ClassificationMatch", "UserGroup", "Attribute", "StringAttribute", "ScriptAttribute", "BooleanAttribute", "DateAttribute", "NumericAttribute", "SingleValueListAttribute", "MultiValueListAttribute", "Comment", "Attachment", "Responsibility", "Workflow", "Job", "Relation", "RelationType", "ComplexRelation", "ComplexRelationType", "ArticulationRule", "Assignment", "Scope", "RelationTrace", "ValidationRule", "DataQualityRule", "DataQualityMetric", "Address", "InstantMessagingAccount", "Email", "PhoneNumber", "Website", "Activity", "FormProperty", "WorkflowTask", "ActivityChange", "WorkflowInstance", "Role", "AttributeType", "BooleanAttributeType", "DateAttributeType", "DateTimeAttributeType", "MultiValueListAttributeType", "NumericAttributeType", "ScriptAttributeType", "SingleValueListAttributeType", "StringAttributeType", "ViewSharingRule", "ViewAssignmentRule", "JdbcDriverFile", "JdbcDriver", "JdbcIngestionProperties", "CsvIngestionProperties", "ExcelIngestionProperties", "ConnectionStringParameter", "AssignedCharacteristicType", "Notification", "Tag", "ComplexRelationLegType", "ComplexRelationAttributeType", "ComplexRelationLeg", "BaseDataType", "AdvancedDataType", "DiagramPicture", "DiagramPictureSharingRule", "DiagramPictureAssignmentRule", "Rating", "Classification", "PhysicalDataConnector", "Context"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and resource_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `resource_type` ({0}), must be one of {1}"  # noqa: E501
                .format(resource_type, allowed_values)
            )

        self._resource_type = resource_type

    @property
    def name(self):
        """Gets the name of this WorkflowDefinitionImpl.  # noqa: E501

        The name of the resource.  # noqa: E501

        :return: The name of this WorkflowDefinitionImpl.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this WorkflowDefinitionImpl.

        The name of the resource.  # noqa: E501

        :param name: The name of this WorkflowDefinitionImpl.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def description(self):
        """Gets the description of this WorkflowDefinitionImpl.  # noqa: E501

        The description of the resource.  # noqa: E501

        :return: The description of this WorkflowDefinitionImpl.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this WorkflowDefinitionImpl.

        The description of the resource.  # noqa: E501

        :param description: The description of this WorkflowDefinitionImpl.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def process_id(self):
        """Gets the process_id of this WorkflowDefinitionImpl.  # noqa: E501

        The <code>id</code> that uniquely identifies a workflow definition in the application.<p>It is present in the BPMN notation in the ID property of the '<process..' tag. Deploying a BPMN in DGC creates a new version if a process with the same ID already exists.  # noqa: E501

        :return: The process_id of this WorkflowDefinitionImpl.  # noqa: E501
        :rtype: str
        """
        return self._process_id

    @process_id.setter
    def process_id(self, process_id):
        """Sets the process_id of this WorkflowDefinitionImpl.

        The <code>id</code> that uniquely identifies a workflow definition in the application.<p>It is present in the BPMN notation in the ID property of the '<process..' tag. Deploying a BPMN in DGC creates a new version if a process with the same ID already exists.  # noqa: E501

        :param process_id: The process_id of this WorkflowDefinitionImpl.  # noqa: E501
        :type: str
        """

        self._process_id = process_id

    @property
    def start_label(self):
        """Gets the start_label of this WorkflowDefinitionImpl.  # noqa: E501

        The label used for starting this workflow.  # noqa: E501

        :return: The start_label of this WorkflowDefinitionImpl.  # noqa: E501
        :rtype: str
        """
        return self._start_label

    @start_label.setter
    def start_label(self, start_label):
        """Sets the start_label of this WorkflowDefinitionImpl.

        The label used for starting this workflow.  # noqa: E501

        :param start_label: The start_label of this WorkflowDefinitionImpl.  # noqa: E501
        :type: str
        """

        self._start_label = start_label

    @property
    def form_required(self):
        """Gets the form_required of this WorkflowDefinitionImpl.  # noqa: E501

        Whether the start event for this workflow requires user interaction through a form or not.  # noqa: E501

        :return: The form_required of this WorkflowDefinitionImpl.  # noqa: E501
        :rtype: bool
        """
        return self._form_required

    @form_required.setter
    def form_required(self, form_required):
        """Sets the form_required of this WorkflowDefinitionImpl.

        Whether the start event for this workflow requires user interaction through a form or not.  # noqa: E501

        :param form_required: The form_required of this WorkflowDefinitionImpl.  # noqa: E501
        :type: bool
        """

        self._form_required = form_required

    @property
    def start_form_key_available(self):
        """Gets the start_form_key_available of this WorkflowDefinitionImpl.  # noqa: E501

        @deprecated This field will be removed in the future. Please, use 'startFormJsonModelAvailable' to recognize if start form model is available.  # noqa: E501

        :return: The start_form_key_available of this WorkflowDefinitionImpl.  # noqa: E501
        :rtype: bool
        """
        return self._start_form_key_available

    @start_form_key_available.setter
    def start_form_key_available(self, start_form_key_available):
        """Sets the start_form_key_available of this WorkflowDefinitionImpl.

        @deprecated This field will be removed in the future. Please, use 'startFormJsonModelAvailable' to recognize if start form model is available.  # noqa: E501

        :param start_form_key_available: The start_form_key_available of this WorkflowDefinitionImpl.  # noqa: E501
        :type: bool
        """

        self._start_form_key_available = start_form_key_available

    @property
    def start_form_json_model_available(self):
        """Gets the start_form_json_model_available of this WorkflowDefinitionImpl.  # noqa: E501

        Whether the workflow has the start form json model available or not. If true, then the external form definition for this task is needed to render the task.  # noqa: E501

        :return: The start_form_json_model_available of this WorkflowDefinitionImpl.  # noqa: E501
        :rtype: bool
        """
        return self._start_form_json_model_available

    @start_form_json_model_available.setter
    def start_form_json_model_available(self, start_form_json_model_available):
        """Sets the start_form_json_model_available of this WorkflowDefinitionImpl.

        Whether the workflow has the start form json model available or not. If true, then the external form definition for this task is needed to render the task.  # noqa: E501

        :param start_form_json_model_available: The start_form_json_model_available of this WorkflowDefinitionImpl.  # noqa: E501
        :type: bool
        """

        self._start_form_json_model_available = start_form_json_model_available

    @property
    def enabled(self):
        """Gets the enabled of this WorkflowDefinitionImpl.  # noqa: E501

        Whether workflow is enabled or not.<p>A workflow has to be enabled for a user to be able to start a workflow. A workflow is enabled if it's status is put on the status 'enabled'  # noqa: E501

        :return: The enabled of this WorkflowDefinitionImpl.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this WorkflowDefinitionImpl.

        Whether workflow is enabled or not.<p>A workflow has to be enabled for a user to be able to start a workflow. A workflow is enabled if it's status is put on the status 'enabled'  # noqa: E501

        :param enabled: The enabled of this WorkflowDefinitionImpl.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def domain_assignment_rules(self):
        """Gets the domain_assignment_rules of this WorkflowDefinitionImpl.  # noqa: E501

        The list of domain assignment rules.  # noqa: E501

        :return: The domain_assignment_rules of this WorkflowDefinitionImpl.  # noqa: E501
        :rtype: list[AssetAssignmentRuleImpl]
        """
        return self._domain_assignment_rules

    @domain_assignment_rules.setter
    def domain_assignment_rules(self, domain_assignment_rules):
        """Sets the domain_assignment_rules of this WorkflowDefinitionImpl.

        The list of domain assignment rules.  # noqa: E501

        :param domain_assignment_rules: The domain_assignment_rules of this WorkflowDefinitionImpl.  # noqa: E501
        :type: list[AssetAssignmentRuleImpl]
        """

        self._domain_assignment_rules = domain_assignment_rules

    @property
    def asset_assignment_rules(self):
        """Gets the asset_assignment_rules of this WorkflowDefinitionImpl.  # noqa: E501

        The list of asset assignment rules.  # noqa: E501

        :return: The asset_assignment_rules of this WorkflowDefinitionImpl.  # noqa: E501
        :rtype: list[AssetAssignmentRuleImpl]
        """
        return self._asset_assignment_rules

    @asset_assignment_rules.setter
    def asset_assignment_rules(self, asset_assignment_rules):
        """Sets the asset_assignment_rules of this WorkflowDefinitionImpl.

        The list of asset assignment rules.  # noqa: E501

        :param asset_assignment_rules: The asset_assignment_rules of this WorkflowDefinitionImpl.  # noqa: E501
        :type: list[AssetAssignmentRuleImpl]
        """

        self._asset_assignment_rules = asset_assignment_rules

    @property
    def business_item_resource_type(self):
        """Gets the business_item_resource_type of this WorkflowDefinitionImpl.  # noqa: E501

        The type of business item that the workflow can refer to. This could be either Community, Domain, Asset, or global.  # noqa: E501

        :return: The business_item_resource_type of this WorkflowDefinitionImpl.  # noqa: E501
        :rtype: str
        """
        return self._business_item_resource_type

    @business_item_resource_type.setter
    def business_item_resource_type(self, business_item_resource_type):
        """Sets the business_item_resource_type of this WorkflowDefinitionImpl.

        The type of business item that the workflow can refer to. This could be either Community, Domain, Asset, or global.  # noqa: E501

        :param business_item_resource_type: The business_item_resource_type of this WorkflowDefinitionImpl.  # noqa: E501
        :type: str
        """
        allowed_values = ["ASSET", "DOMAIN", "COMMUNITY", "GLOBAL"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and business_item_resource_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `business_item_resource_type` ({0}), must be one of {1}"  # noqa: E501
                .format(business_item_resource_type, allowed_values)
            )

        self._business_item_resource_type = business_item_resource_type

    @property
    def exclusivity(self):
        """Gets the exclusivity of this WorkflowDefinitionImpl.  # noqa: E501

        The exclusivity of this workflow. This determines how many times a workflow can be started for a specific resource.  # noqa: E501

        :return: The exclusivity of this WorkflowDefinitionImpl.  # noqa: E501
        :rtype: str
        """
        return self._exclusivity

    @exclusivity.setter
    def exclusivity(self, exclusivity):
        """Sets the exclusivity of this WorkflowDefinitionImpl.

        The exclusivity of this workflow. This determines how many times a workflow can be started for a specific resource.  # noqa: E501

        :param exclusivity: The exclusivity of this WorkflowDefinitionImpl.  # noqa: E501
        :type: str
        """
        allowed_values = ["RESOURCE_EXCLUSIVITY", "DEFINITION_EXCLUSIVITY", "UNCONSTRAINED"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and exclusivity not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `exclusivity` ({0}), must be one of {1}"  # noqa: E501
                .format(exclusivity, allowed_values)
            )

        self._exclusivity = exclusivity

    @property
    def guest_user_accessible(self):
        """Gets the guest_user_accessible of this WorkflowDefinitionImpl.  # noqa: E501

        Whether this workflow definition is guest user accessible.  # noqa: E501

        :return: The guest_user_accessible of this WorkflowDefinitionImpl.  # noqa: E501
        :rtype: bool
        """
        return self._guest_user_accessible

    @guest_user_accessible.setter
    def guest_user_accessible(self, guest_user_accessible):
        """Sets the guest_user_accessible of this WorkflowDefinitionImpl.

        Whether this workflow definition is guest user accessible.  # noqa: E501

        :param guest_user_accessible: The guest_user_accessible of this WorkflowDefinitionImpl.  # noqa: E501
        :type: bool
        """

        self._guest_user_accessible = guest_user_accessible

    @property
    def registered_user_accessible(self):
        """Gets the registered_user_accessible of this WorkflowDefinitionImpl.  # noqa: E501

        Whether the workflow definition is accessible by any registered user.  # noqa: E501

        :return: The registered_user_accessible of this WorkflowDefinitionImpl.  # noqa: E501
        :rtype: bool
        """
        return self._registered_user_accessible

    @registered_user_accessible.setter
    def registered_user_accessible(self, registered_user_accessible):
        """Sets the registered_user_accessible of this WorkflowDefinitionImpl.

        Whether the workflow definition is accessible by any registered user.  # noqa: E501

        :param registered_user_accessible: The registered_user_accessible of this WorkflowDefinitionImpl.  # noqa: E501
        :type: bool
        """

        self._registered_user_accessible = registered_user_accessible

    @property
    def candidate_user_check_enabled(self):
        """Gets the candidate_user_check_enabled of this WorkflowDefinitionImpl.  # noqa: E501

        Whether the candidate user check for this workflow is enabled.  # noqa: E501

        :return: The candidate_user_check_enabled of this WorkflowDefinitionImpl.  # noqa: E501
        :rtype: bool
        """
        return self._candidate_user_check_enabled

    @candidate_user_check_enabled.setter
    def candidate_user_check_enabled(self, candidate_user_check_enabled):
        """Sets the candidate_user_check_enabled of this WorkflowDefinitionImpl.

        Whether the candidate user check for this workflow is enabled.  # noqa: E501

        :param candidate_user_check_enabled: The candidate_user_check_enabled of this WorkflowDefinitionImpl.  # noqa: E501
        :type: bool
        """

        self._candidate_user_check_enabled = candidate_user_check_enabled

    @property
    def global_create(self):
        """Gets the global_create of this WorkflowDefinitionImpl.  # noqa: E501

        Whether the workflow is accessible from the global create menu.  # noqa: E501

        :return: The global_create of this WorkflowDefinitionImpl.  # noqa: E501
        :rtype: bool
        """
        return self._global_create

    @global_create.setter
    def global_create(self, global_create):
        """Sets the global_create of this WorkflowDefinitionImpl.

        Whether the workflow is accessible from the global create menu.  # noqa: E501

        :param global_create: The global_create of this WorkflowDefinitionImpl.  # noqa: E501
        :type: bool
        """

        self._global_create = global_create

    @property
    def start_events(self):
        """Gets the start_events of this WorkflowDefinitionImpl.  # noqa: E501

        The start events in a list of WorkflowStartEventType enums.  # noqa: E501

        :return: The start_events of this WorkflowDefinitionImpl.  # noqa: E501
        :rtype: list[str]
        """
        return self._start_events

    @start_events.setter
    def start_events(self, start_events):
        """Sets the start_events of this WorkflowDefinitionImpl.

        The start events in a list of WorkflowStartEventType enums.  # noqa: E501

        :param start_events: The start_events of this WorkflowDefinitionImpl.  # noqa: E501
        :type: list[str]
        """
        allowed_values = ["ASSET_ADDED", "ASSET_REMOVED", "ASSET_STATUS_CHANGED", "ASSET_DOMAIN_CHANGED", "ASSET_TYPE_CHANGED", "ASSET_ATTRIBUTE_CHANGED", "ASSET_NAME_CHANGED", "ASSET_DISPLAY_NAME_CHANGED", "ASSET_ATTRIBUTE_ADDED", "ASSET_ATTRIBUTE_REMOVED", "DOMAIN_ADDED", "DOMAIN_REMOVED", "ROLE_GRANTED", "ROLE_REVOKED", "WORKFLOW_STARTED", "WORKFLOW_CANCELED", "WORKLFLOW_ESCALATION", "WORKFLOW_TASK_COMPLETED", "USER_ADDED", "USER_REMOVED", "USER_DISABLED", "COMMENT_ADDED", "COMMENT_REMOVED", "COMMENT_CHANGED", "RELATION_ADDED_AND_ASSET_IS_SOURCE", "RELATION_REMOVED_AND_ASSET_WAS_SOURCE", "RELATION_ADDED_AND_ASSET_IS_TARGET", "RELATION_REMOVED_AND_ASSET_WAS_TARGET", "TAG_ASSIGN_CHANGED", "CLASSIFICATION_MATCH_ACCEPTED", "CLASSIFICATION_MATCH_REJECTED", "CLASSIFICATION_MATCH_ADDED", "CLASSIFICATION_MATCH_REMOVED", "CLASSIFICATION_MATCH_UPDATED", "DATABASE_REGISTRATION_COMPLETED", "DATABASE_REGISTRATION_FAILED"]  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                not set(start_events).issubset(set(allowed_values))):  # noqa: E501
            raise ValueError(
                "Invalid values for `start_events` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(start_events) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._start_events = start_events

    @property
    def configuration_variables(self):
        """Gets the configuration_variables of this WorkflowDefinitionImpl.  # noqa: E501

        The map of configuration variable key-value pairs.  # noqa: E501

        :return: The configuration_variables of this WorkflowDefinitionImpl.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._configuration_variables

    @configuration_variables.setter
    def configuration_variables(self, configuration_variables):
        """Sets the configuration_variables of this WorkflowDefinitionImpl.

        The map of configuration variable key-value pairs.  # noqa: E501

        :param configuration_variables: The configuration_variables of this WorkflowDefinitionImpl.  # noqa: E501
        :type: dict(str, str)
        """

        self._configuration_variables = configuration_variables

    @property
    def start_roles(self):
        """Gets the start_roles of this WorkflowDefinitionImpl.  # noqa: E501

        The roles allowed to start the process.  # noqa: E501

        :return: The start_roles of this WorkflowDefinitionImpl.  # noqa: E501
        :rtype: list[RoleImpl]
        """
        return self._start_roles

    @start_roles.setter
    def start_roles(self, start_roles):
        """Sets the start_roles of this WorkflowDefinitionImpl.

        The roles allowed to start the process.  # noqa: E501

        :param start_roles: The start_roles of this WorkflowDefinitionImpl.  # noqa: E501
        :type: list[RoleImpl]
        """

        self._start_roles = start_roles

    @property
    def stop_roles(self):
        """Gets the stop_roles of this WorkflowDefinitionImpl.  # noqa: E501

        The roles allowed to stop processes/tasks.  # noqa: E501

        :return: The stop_roles of this WorkflowDefinitionImpl.  # noqa: E501
        :rtype: list[RoleImpl]
        """
        return self._stop_roles

    @stop_roles.setter
    def stop_roles(self, stop_roles):
        """Sets the stop_roles of this WorkflowDefinitionImpl.

        The roles allowed to stop processes/tasks.  # noqa: E501

        :param stop_roles: The stop_roles of this WorkflowDefinitionImpl.  # noqa: E501
        :type: list[RoleImpl]
        """

        self._stop_roles = stop_roles

    @property
    def reassign_roles(self):
        """Gets the reassign_roles of this WorkflowDefinitionImpl.  # noqa: E501

        The roles allowed to reassign tasks.  # noqa: E501

        :return: The reassign_roles of this WorkflowDefinitionImpl.  # noqa: E501
        :rtype: list[RoleImpl]
        """
        return self._reassign_roles

    @reassign_roles.setter
    def reassign_roles(self, reassign_roles):
        """Sets the reassign_roles of this WorkflowDefinitionImpl.

        The roles allowed to reassign tasks.  # noqa: E501

        :param reassign_roles: The reassign_roles of this WorkflowDefinitionImpl.  # noqa: E501
        :type: list[RoleImpl]
        """

        self._reassign_roles = reassign_roles

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WorkflowDefinitionImpl):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, WorkflowDefinitionImpl):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import collibra_core
from collibra_core.models.dgc_session import DGCSession  # noqa: E501
from collibra_core.rest import ApiException

class TestDGCSession(unittest.TestCase):
    """DGCSession unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test DGCSession
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = collibra_core.models.dgc_session.DGCSession()  # noqa: E501
        if include_optional :
            return DGCSession(
                csrf_token = '0', 
                user = collibra_core.models.user.User(
                    id = '0', 
                    created_by = '4d250cc5-e583-4640-9874-b93d82c7a6cb', 
                    created_on = 1475503010320, 
                    last_modified_by = 'a073ff90-e7bc-4b35-ba90-c4d475f642fe', 
                    last_modified_on = 1476703764163, 
                    system = True, 
                    resource_type = 'View', 
                    user_name = '0', 
                    first_name = '0', 
                    last_name = '0', 
                    email_address = '0', 
                    gender = 'MALE', 
                    language = '0', 
                    additional_email_addresses = [
                        collibra_core.models.email.Email(
                            id = '0', 
                            created_by = '4d250cc5-e583-4640-9874-b93d82c7a6cb', 
                            created_on = 1475503010320, 
                            last_modified_by = 'a073ff90-e7bc-4b35-ba90-c4d475f642fe', 
                            last_modified_on = 1476703764163, 
                            system = True, 
                            resource_type = 'View', 
                            email_address = '0', )
                        ], 
                    phone_numbers = [
                        collibra_core.models.phone_number.PhoneNumber(
                            id = '0', 
                            created_by = '4d250cc5-e583-4640-9874-b93d82c7a6cb', 
                            created_on = 1475503010320, 
                            last_modified_by = 'a073ff90-e7bc-4b35-ba90-c4d475f642fe', 
                            last_modified_on = 1476703764163, 
                            system = True, 
                            resource_type = 'View', 
                            type = 'FAX', 
                            phone_number = '0', )
                        ], 
                    instant_messaging_accounts = [
                        collibra_core.models.instant_messaging_account.InstantMessagingAccount(
                            id = '0', 
                            created_by = '4d250cc5-e583-4640-9874-b93d82c7a6cb', 
                            created_on = 1475503010320, 
                            last_modified_by = 'a073ff90-e7bc-4b35-ba90-c4d475f642fe', 
                            last_modified_on = 1476703764163, 
                            system = True, 
                            resource_type = 'View', 
                            account = '0', 
                            type = 'AOL', )
                        ], 
                    websites = [
                        collibra_core.models.website.Website(
                            id = '0', 
                            created_by = '4d250cc5-e583-4640-9874-b93d82c7a6cb', 
                            created_on = 1475503010320, 
                            last_modified_by = 'a073ff90-e7bc-4b35-ba90-c4d475f642fe', 
                            last_modified_on = 1476703764163, 
                            system = True, 
                            resource_type = 'View', 
                            url = '0', 
                            type = 'FACEBOOK', )
                        ], 
                    addresses = [
                        collibra_core.models.address.Address(
                            id = '0', 
                            created_by = '4d250cc5-e583-4640-9874-b93d82c7a6cb', 
                            created_on = 1475503010320, 
                            last_modified_by = 'a073ff90-e7bc-4b35-ba90-c4d475f642fe', 
                            last_modified_on = 1476703764163, 
                            system = True, 
                            resource_type = 'View', 
                            city = '0', 
                            street = '0', 
                            number = '0', 
                            state = '0', 
                            country = '0', 
                            postal_code = '0', 
                            type = 'HOME', )
                        ], 
                    activated = True, 
                    enabled = True, 
                    ldap_user = True, 
                    user_source = 'INTERNAL', 
                    guest_user = True, 
                    api_user = True, 
                    license_type = 'CONSUMER', )
            )
        else :
            return DGCSession(
        )

    def testDGCSession(self):
        """Test DGCSession"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import collibra_core
from collibra_core.api.domains_api import DomainsApi  # noqa: E501
from collibra_core.rest import ApiException


class TestDomainsApi(unittest.TestCase):
    """DomainsApi unit test stubs"""

    def setUp(self):
        self.api = collibra_core.api.domains_api.DomainsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_domain(self):
        """Test case for add_domain

        Add domain  # noqa: E501
        """
        pass

    def test_add_domains(self):
        """Test case for add_domains

        Add multpile domains  # noqa: E501
        """
        pass

    def test_change_domain(self):
        """Test case for change_domain

        Change domain  # noqa: E501
        """
        pass

    def test_change_domains(self):
        """Test case for change_domains

        Change multiple domains  # noqa: E501
        """
        pass

    def test_find_domains(self):
        """Test case for find_domains

        Search domains  # noqa: E501
        """
        pass

    def test_get_domain(self):
        """Test case for get_domain

        Get domain  # noqa: E501
        """
        pass

    def test_get_domain_breadcrumb(self):
        """Test case for get_domain_breadcrumb

        Get domain breadcrumb  # noqa: E501
        """
        pass

    def test_remove_domain(self):
        """Test case for remove_domain

        Remove domain  # noqa: E501
        """
        pass

    def test_remove_domains(self):
        """Test case for remove_domains

        Remove multiple domains  # noqa: E501
        """
        pass

    def test_remove_domains_in_job(self):
        """Test case for remove_domains_in_job

        Remove multiple domains asynchronously  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from collibra_core.configuration import Configuration


class AssignmentImpl(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'created_by': 'str',
        'created_on': 'int',
        'last_modified_by': 'str',
        'last_modified_on': 'int',
        'system': 'bool',
        'resource_type': 'str',
        'asset_type': 'NamedResourceReferenceImpl',
        'statuses': 'list[NamedDescribedResourceReference]',
        'default_status_id': 'str',
        'characteristic_types': 'list[AssignedCharacteristicType]',
        'articulation_rules': 'list[ArticulationRuleImpl]',
        'validation_rules': 'list[NamedResourceReferenceImpl]',
        'data_quality_rules': 'list[NamedDescribedResourceReference]',
        'domain_types': 'list[NamedDescribedResourceReference]',
        'scope': 'ScopeImpl'
    }

    attribute_map = {
        'id': 'id',
        'created_by': 'createdBy',
        'created_on': 'createdOn',
        'last_modified_by': 'lastModifiedBy',
        'last_modified_on': 'lastModifiedOn',
        'system': 'system',
        'resource_type': 'resourceType',
        'asset_type': 'assetType',
        'statuses': 'statuses',
        'default_status_id': 'defaultStatusId',
        'characteristic_types': 'characteristicTypes',
        'articulation_rules': 'articulationRules',
        'validation_rules': 'validationRules',
        'data_quality_rules': 'dataQualityRules',
        'domain_types': 'domainTypes',
        'scope': 'scope'
    }

    def __init__(self, id=None, created_by=None, created_on=None, last_modified_by=None, last_modified_on=None, system=None, resource_type=None, asset_type=None, statuses=None, default_status_id=None, characteristic_types=None, articulation_rules=None, validation_rules=None, data_quality_rules=None, domain_types=None, scope=None, local_vars_configuration=None):  # noqa: E501
        """AssignmentImpl - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._created_by = None
        self._created_on = None
        self._last_modified_by = None
        self._last_modified_on = None
        self._system = None
        self._resource_type = None
        self._asset_type = None
        self._statuses = None
        self._default_status_id = None
        self._characteristic_types = None
        self._articulation_rules = None
        self._validation_rules = None
        self._data_quality_rules = None
        self._domain_types = None
        self._scope = None
        self.discriminator = None

        self.id = id
        if created_by is not None:
            self.created_by = created_by
        if created_on is not None:
            self.created_on = created_on
        if last_modified_by is not None:
            self.last_modified_by = last_modified_by
        if last_modified_on is not None:
            self.last_modified_on = last_modified_on
        if system is not None:
            self.system = system
        self.resource_type = resource_type
        if asset_type is not None:
            self.asset_type = asset_type
        if statuses is not None:
            self.statuses = statuses
        if default_status_id is not None:
            self.default_status_id = default_status_id
        if characteristic_types is not None:
            self.characteristic_types = characteristic_types
        if articulation_rules is not None:
            self.articulation_rules = articulation_rules
        if validation_rules is not None:
            self.validation_rules = validation_rules
        if data_quality_rules is not None:
            self.data_quality_rules = data_quality_rules
        if domain_types is not None:
            self.domain_types = domain_types
        if scope is not None:
            self.scope = scope

    @property
    def id(self):
        """Gets the id of this AssignmentImpl.  # noqa: E501

        The id of the represented object (entity).  # noqa: E501

        :return: The id of this AssignmentImpl.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this AssignmentImpl.

        The id of the represented object (entity).  # noqa: E501

        :param id: The id of this AssignmentImpl.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def created_by(self):
        """Gets the created_by of this AssignmentImpl.  # noqa: E501

        The id of the user that created this resource.  # noqa: E501

        :return: The created_by of this AssignmentImpl.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this AssignmentImpl.

        The id of the user that created this resource.  # noqa: E501

        :param created_by: The created_by of this AssignmentImpl.  # noqa: E501
        :type: str
        """

        self._created_by = created_by

    @property
    def created_on(self):
        """Gets the created_on of this AssignmentImpl.  # noqa: E501

        The timestamp (in UTC time standard) of the creation of this resource.  # noqa: E501

        :return: The created_on of this AssignmentImpl.  # noqa: E501
        :rtype: int
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this AssignmentImpl.

        The timestamp (in UTC time standard) of the creation of this resource.  # noqa: E501

        :param created_on: The created_on of this AssignmentImpl.  # noqa: E501
        :type: int
        """

        self._created_on = created_on

    @property
    def last_modified_by(self):
        """Gets the last_modified_by of this AssignmentImpl.  # noqa: E501

        The id of the user who modified this resource the last time.  # noqa: E501

        :return: The last_modified_by of this AssignmentImpl.  # noqa: E501
        :rtype: str
        """
        return self._last_modified_by

    @last_modified_by.setter
    def last_modified_by(self, last_modified_by):
        """Sets the last_modified_by of this AssignmentImpl.

        The id of the user who modified this resource the last time.  # noqa: E501

        :param last_modified_by: The last_modified_by of this AssignmentImpl.  # noqa: E501
        :type: str
        """

        self._last_modified_by = last_modified_by

    @property
    def last_modified_on(self):
        """Gets the last_modified_on of this AssignmentImpl.  # noqa: E501

        The timestamp (in UTC time standard) of the last modification of this resource.  # noqa: E501

        :return: The last_modified_on of this AssignmentImpl.  # noqa: E501
        :rtype: int
        """
        return self._last_modified_on

    @last_modified_on.setter
    def last_modified_on(self, last_modified_on):
        """Sets the last_modified_on of this AssignmentImpl.

        The timestamp (in UTC time standard) of the last modification of this resource.  # noqa: E501

        :param last_modified_on: The last_modified_on of this AssignmentImpl.  # noqa: E501
        :type: int
        """

        self._last_modified_on = last_modified_on

    @property
    def system(self):
        """Gets the system of this AssignmentImpl.  # noqa: E501

        Whether this is a system resource or not.  # noqa: E501

        :return: The system of this AssignmentImpl.  # noqa: E501
        :rtype: bool
        """
        return self._system

    @system.setter
    def system(self, system):
        """Sets the system of this AssignmentImpl.

        Whether this is a system resource or not.  # noqa: E501

        :param system: The system of this AssignmentImpl.  # noqa: E501
        :type: bool
        """

        self._system = system

    @property
    def resource_type(self):
        """Gets the resource_type of this AssignmentImpl.  # noqa: E501

        The type of this resource, i.e. [Community, Asset, Domain, Attribute, Relation, WorkflowInstance].  # noqa: E501

        :return: The resource_type of this AssignmentImpl.  # noqa: E501
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this AssignmentImpl.

        The type of this resource, i.e. [Community, Asset, Domain, Attribute, Relation, WorkflowInstance].  # noqa: E501

        :param resource_type: The resource_type of this AssignmentImpl.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and resource_type is None:  # noqa: E501
            raise ValueError("Invalid value for `resource_type`, must not be `None`")  # noqa: E501
        allowed_values = ["View", "Asset", "Community", "Domain", "AssetType", "DomainType", "Status", "User", "ClassificationMatch", "UserGroup", "Attribute", "StringAttribute", "ScriptAttribute", "BooleanAttribute", "DateAttribute", "NumericAttribute", "SingleValueListAttribute", "MultiValueListAttribute", "Comment", "Attachment", "Responsibility", "Workflow", "Job", "Relation", "RelationType", "ComplexRelation", "ComplexRelationType", "ArticulationRule", "Assignment", "Scope", "RelationTrace", "ValidationRule", "DataQualityRule", "DataQualityMetric", "Address", "InstantMessagingAccount", "Email", "PhoneNumber", "Website", "Activity", "FormProperty", "WorkflowTask", "ActivityChange", "WorkflowInstance", "Role", "AttributeType", "BooleanAttributeType", "DateAttributeType", "DateTimeAttributeType", "MultiValueListAttributeType", "NumericAttributeType", "ScriptAttributeType", "SingleValueListAttributeType", "StringAttributeType", "ViewSharingRule", "ViewAssignmentRule", "JdbcDriverFile", "JdbcDriver", "JdbcIngestionProperties", "CsvIngestionProperties", "ExcelIngestionProperties", "ConnectionStringParameter", "AssignedCharacteristicType", "Notification", "Tag", "ComplexRelationLegType", "ComplexRelationAttributeType", "ComplexRelationLeg", "BaseDataType", "AdvancedDataType", "DiagramPicture", "DiagramPictureSharingRule", "DiagramPictureAssignmentRule", "Rating", "Classification", "PhysicalDataConnector", "Context"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and resource_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `resource_type` ({0}), must be one of {1}"  # noqa: E501
                .format(resource_type, allowed_values)
            )

        self._resource_type = resource_type

    @property
    def asset_type(self):
        """Gets the asset_type of this AssignmentImpl.  # noqa: E501


        :return: The asset_type of this AssignmentImpl.  # noqa: E501
        :rtype: NamedResourceReferenceImpl
        """
        return self._asset_type

    @asset_type.setter
    def asset_type(self, asset_type):
        """Sets the asset_type of this AssignmentImpl.


        :param asset_type: The asset_type of this AssignmentImpl.  # noqa: E501
        :type: NamedResourceReferenceImpl
        """

        self._asset_type = asset_type

    @property
    def statuses(self):
        """Gets the statuses of this AssignmentImpl.  # noqa: E501

        The list of references to the statuses.  # noqa: E501

        :return: The statuses of this AssignmentImpl.  # noqa: E501
        :rtype: list[NamedDescribedResourceReference]
        """
        return self._statuses

    @statuses.setter
    def statuses(self, statuses):
        """Sets the statuses of this AssignmentImpl.

        The list of references to the statuses.  # noqa: E501

        :param statuses: The statuses of this AssignmentImpl.  # noqa: E501
        :type: list[NamedDescribedResourceReference]
        """

        self._statuses = statuses

    @property
    def default_status_id(self):
        """Gets the default_status_id of this AssignmentImpl.  # noqa: E501

        The ID of the default status.  # noqa: E501

        :return: The default_status_id of this AssignmentImpl.  # noqa: E501
        :rtype: str
        """
        return self._default_status_id

    @default_status_id.setter
    def default_status_id(self, default_status_id):
        """Sets the default_status_id of this AssignmentImpl.

        The ID of the default status.  # noqa: E501

        :param default_status_id: The default_status_id of this AssignmentImpl.  # noqa: E501
        :type: str
        """

        self._default_status_id = default_status_id

    @property
    def characteristic_types(self):
        """Gets the characteristic_types of this AssignmentImpl.  # noqa: E501

        The list of assigned characteristic types such as attribute types, relation types and complex relation types. Depending on the actual type, a characteristic type may contain additional properties. For additional details, refer to the schemas of AssignedAttributeType, AssignedComplexRelationType and AssignedRelationType.  # noqa: E501

        :return: The characteristic_types of this AssignmentImpl.  # noqa: E501
        :rtype: list[AssignedCharacteristicType]
        """
        return self._characteristic_types

    @characteristic_types.setter
    def characteristic_types(self, characteristic_types):
        """Sets the characteristic_types of this AssignmentImpl.

        The list of assigned characteristic types such as attribute types, relation types and complex relation types. Depending on the actual type, a characteristic type may contain additional properties. For additional details, refer to the schemas of AssignedAttributeType, AssignedComplexRelationType and AssignedRelationType.  # noqa: E501

        :param characteristic_types: The characteristic_types of this AssignmentImpl.  # noqa: E501
        :type: list[AssignedCharacteristicType]
        """

        self._characteristic_types = characteristic_types

    @property
    def articulation_rules(self):
        """Gets the articulation_rules of this AssignmentImpl.  # noqa: E501

        The list of articulation rules applying with the assignment.  # noqa: E501

        :return: The articulation_rules of this AssignmentImpl.  # noqa: E501
        :rtype: list[ArticulationRuleImpl]
        """
        return self._articulation_rules

    @articulation_rules.setter
    def articulation_rules(self, articulation_rules):
        """Sets the articulation_rules of this AssignmentImpl.

        The list of articulation rules applying with the assignment.  # noqa: E501

        :param articulation_rules: The articulation_rules of this AssignmentImpl.  # noqa: E501
        :type: list[ArticulationRuleImpl]
        """

        self._articulation_rules = articulation_rules

    @property
    def validation_rules(self):
        """Gets the validation_rules of this AssignmentImpl.  # noqa: E501

        The list of references to validation rules applying with the assignment.  # noqa: E501

        :return: The validation_rules of this AssignmentImpl.  # noqa: E501
        :rtype: list[NamedResourceReferenceImpl]
        """
        return self._validation_rules

    @validation_rules.setter
    def validation_rules(self, validation_rules):
        """Sets the validation_rules of this AssignmentImpl.

        The list of references to validation rules applying with the assignment.  # noqa: E501

        :param validation_rules: The validation_rules of this AssignmentImpl.  # noqa: E501
        :type: list[NamedResourceReferenceImpl]
        """

        self._validation_rules = validation_rules

    @property
    def data_quality_rules(self):
        """Gets the data_quality_rules of this AssignmentImpl.  # noqa: E501

        The list of references to data quality rules applying with the assignment.  # noqa: E501

        :return: The data_quality_rules of this AssignmentImpl.  # noqa: E501
        :rtype: list[NamedDescribedResourceReference]
        """
        return self._data_quality_rules

    @data_quality_rules.setter
    def data_quality_rules(self, data_quality_rules):
        """Sets the data_quality_rules of this AssignmentImpl.

        The list of references to data quality rules applying with the assignment.  # noqa: E501

        :param data_quality_rules: The data_quality_rules of this AssignmentImpl.  # noqa: E501
        :type: list[NamedDescribedResourceReference]
        """

        self._data_quality_rules = data_quality_rules

    @property
    def domain_types(self):
        """Gets the domain_types of this AssignmentImpl.  # noqa: E501

        The list of references to domain types which the assignment refers to.  # noqa: E501

        :return: The domain_types of this AssignmentImpl.  # noqa: E501
        :rtype: list[NamedDescribedResourceReference]
        """
        return self._domain_types

    @domain_types.setter
    def domain_types(self, domain_types):
        """Sets the domain_types of this AssignmentImpl.

        The list of references to domain types which the assignment refers to.  # noqa: E501

        :param domain_types: The domain_types of this AssignmentImpl.  # noqa: E501
        :type: list[NamedDescribedResourceReference]
        """

        self._domain_types = domain_types

    @property
    def scope(self):
        """Gets the scope of this AssignmentImpl.  # noqa: E501


        :return: The scope of this AssignmentImpl.  # noqa: E501
        :rtype: ScopeImpl
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """Sets the scope of this AssignmentImpl.


        :param scope: The scope of this AssignmentImpl.  # noqa: E501
        :type: ScopeImpl
        """

        self._scope = scope

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AssignmentImpl):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AssignmentImpl):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import collibra_core
from collibra_core.api.users_api import UsersApi  # noqa: E501
from collibra_core.rest import ApiException


class TestUsersApi(unittest.TestCase):
    """UsersApi unit test stubs"""

    def setUp(self):
        self.api = collibra_core.api.users_api.UsersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_user(self):
        """Test case for add_user

        Adds a new user  # noqa: E501
        """
        pass

    def test_add_user_groups_for_user(self):
        """Test case for add_user_groups_for_user

        Add a user to multiple user groups  # noqa: E501
        """
        pass

    def test_add_users(self):
        """Test case for add_users

        Adds multiple new users  # noqa: E501
        """
        pass

    def test_change_user(self):
        """Test case for change_user

        Changes the user with the information that is present in the request  # noqa: E501
        """
        pass

    def test_change_user_avatar(self):
        """Test case for change_user_avatar

        Changes the avatar for the user identified by the given ID  # noqa: E501
        """
        pass

    def test_delete_user(self):
        """Test case for delete_user

        Deletes the user with the given ID  # noqa: E501
        """
        pass

    def test_delete_user_avatar(self):
        """Test case for delete_user_avatar

        Deletes the avatar for the user identified by the given ID  # noqa: E501
        """
        pass

    def test_find_users(self):
        """Test case for find_users

        Returns users matching the given search criteria  # noqa: E501
        """
        pass

    def test_get_avatar_file(self):
        """Test case for get_avatar_file

        Get the avatar image for the user with the given ID  # noqa: E501
        """
        pass

    def test_get_current_user(self):
        """Test case for get_current_user

        Returns the current user, if logged in  # noqa: E501
        """
        pass

    def test_get_current_user_permissions(self):
        """Test case for get_current_user_permissions

        Returns the current user global permissions, if logged in  # noqa: E501
        """
        pass

    def test_get_user(self):
        """Test case for get_user

        Gets the user with the given ID  # noqa: E501
        """
        pass

    def test_get_user_by_email_address(self):
        """Test case for get_user_by_email_address

        Gets the user identified by given e-mail address  # noqa: E501
        """
        pass

    def test_get_user_required_license_type(self):
        """Test case for get_user_required_license_type

        Gets the required LicenseType for the given user  # noqa: E501
        """
        pass

    def test_remove_user_from_user_groups(self):
        """Test case for remove_user_from_user_groups

        Removes user from multiple user groups  # noqa: E501
        """
        pass

    def test_set_user_groups_for_user(self):
        """Test case for set_user_groups_for_user

        Sets user groups for the indicated user  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
